OC.L10N.register(
    "news",
    {
    "Download" : "බාන්න",
    "Close" : "වසන්න",
    "Language" : "භාෂාව",
    "Subscribe" : "දායකවන්න",
    "by" : "විසින්",
    "from" : "වෙතින්",
    "Description" : "විස්තරය",
    "Refresh" : "නැවුම් කරන්න",
    "Web address" : "අන්තර්ජාල ලිපිනය",
    "Folder" : "ෆෝල්ඩරය",
    "Folder name" : "ෆොල්ඩරයේ නම",
    "Credentials" : "Credentials",
    "Username" : "පරිශීලක නම",
    "Password" : "මුර පදය",
    "Create" : "තනන්න",
    "Rename" : "නැවත නම් කරන්න",
    "Delete" : "ඉවත් කරන්න",
    "Collapse" : "හකුළන්න",
    "Starred" : "තරු දැමු",
    "Settings" : "සිටුවම්",
    "Import" : "ආයාත කරන්න",
    "Export" : "නිර්යාත කරන්න",
    "Help" : "උදව්",
    "Documentation" : "ලේඛන"
},
"nplurals=2; plural=(n != 1);");
